#include <grass/dbmi.h>

int
db__driver_create_index (dbIndex *index)
{
    return DB_OK;
}
